# -*- coding: utf-8 -*-
#
# This file is part of Zenodo.
# Copyright (C) 2016 CERN.
#
# Zenodo is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Zenodo is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public Licnse
# along with Zenodo; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.

"""Zenodo Serializers."""

from __future__ import absolute_import, print_function

from flask import json
from invenio_records_files.api import Record

from .json import ZenodoJSONSerializer


class LegacyJSONSerializer(ZenodoJSONSerializer):
    """Legacy JSON Serializer."""

    def serialize_search(self, pid_fetcher, search_result, links=None,
                         item_links_factory=None):
        """Serialize as a json array."""
        return json.dumps([self.transform_search_hit(
            pid_fetcher(hit['_id'], hit['_source']),
            hit,
            links_factory=item_links_factory,
        ) for hit in search_result['hits']['hits']])


class DepositLegacyJSONSerializer(LegacyJSONSerializer):
    """Legacy JSON serializer.

    Dumps files directly from Bucket instead of relying on record metadata.
    """

    def preprocess_record(self, pid, record, links_factory=None):
        """Include files for single record retrievals."""
        result = super(LegacyJSONSerializer, self).preprocess_record(
            pid, record, links_factory=links_factory
        )
        if isinstance(record, Record):
            result['files'] = record.files.dumps()
        return result
